@@ -165,8 +165,9 @@ irix_core_core_file_p (abfd)
 		     idg->i_len + idf->i_len + ids->i_len,
 		     0,
 		     idg->i_offset);
-
+ 
   /* OK, we believe you.  You're a core file (sure, sure).  */
+  bfd_default_set_arch_mach (abfd, bfd_arch_mips, 0);
 
   return abfd->xvec;
 }
@@ -270,6 +271,8 @@ const bfd_target irix_core_vec =
        BFD_JUMP_TABLE_LINK (_bfd_nolink),
        BFD_JUMP_TABLE_DYNAMIC (_bfd_nodynamic),
 
+    NULL,
+    
     (PTR) 0			/* backend_data */
 };
 
