@@ -1,5 +1,5 @@
 /* BFD COFF object file private structure.
-   Copyright (C) 1990, 91, 92, 93, 94, 95, 96, 97, 98, 1999
+   Copyright (C) 1990, 91, 92, 93, 94, 95, 96, 97, 98, 1999, 2001
    Free Software Foundation, Inc.
    Written by Cygnus Support.
 
@@ -43,6 +43,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 #define obj_coff_strings(bfd)	(coff_data (bfd)->strings)
 #define obj_coff_keep_strings(bfd) (coff_data (bfd)->keep_strings)
 #define obj_coff_sym_hashes(bfd) (coff_data (bfd)->sym_hashes)
+#define obj_coff_strings_written(bfd) (coff_data (bfd)->strings_written)
 
 #define obj_coff_local_toc_table(bfd) (coff_data(bfd)->local_toc_sym_map)
 
@@ -83,6 +84,8 @@ typedef struct coff_tdata
   char *strings;
   /* If this is true, the strings may not be freed.  */
   boolean keep_strings;
+  /* If this is true, the strings have been written out already.  */
+  boolean strings_written;
 
   /* is this a PE format coff file */
   int pe;
@@ -97,6 +100,9 @@ typedef struct coff_tdata
   /* Used by coff_find_nearest_line.  */
   PTR line_info;
 
+  /* A place to stash dwarf2 info for this bfd. */
+  PTR dwarf2_find_line_info;
+
   /* The timestamp from the COFF file header.  */
   long timestamp;
 
@@ -115,6 +121,8 @@ typedef struct pe_tdata
   int has_reloc_section;
   boolean (*in_reloc_p) PARAMS((bfd *, reloc_howto_type *));
   flagword real_flags;
+  int target_subsystem;
+  boolean force_minimum_alignment;
 } pe_data_type;
 
 #define pe_data(bfd)		((bfd)->tdata.pe_obj_data)
@@ -126,6 +134,9 @@ struct xcoff_tdata
   /* Basic COFF information.  */
   coff_data_type coff;
 
+  /* True if this is an XCOFF64 file. */
+  boolean xcoff64;
+
   /* True if a large a.out header should be generated.  */
   boolean full_aouthdr;
 
@@ -575,32 +586,32 @@ extern boolean ppc_process_before_allocation
 typedef struct coff_ptr_struct
 {
 
-        /* Remembers the offset from the first symbol in the file for
+       /* Remembers the offset from the first symbol in the file for
           this symbol. Generated by coff_renumber_symbols. */
 unsigned int offset;
 
-        /* Should the value of this symbol be renumbered.  Used for
+       /* Should the value of this symbol be renumbered.  Used for
           XCOFF C_BSTAT symbols.  Set by coff_slurp_symbol_table.  */
 unsigned int fix_value : 1;
 
-        /* Should the tag field of this symbol be renumbered.
+       /* Should the tag field of this symbol be renumbered.
           Created by coff_pointerize_aux. */
 unsigned int fix_tag : 1;
 
-        /* Should the endidx field of this symbol be renumbered.
+       /* Should the endidx field of this symbol be renumbered.
           Created by coff_pointerize_aux. */
 unsigned int fix_end : 1;
 
-        /* Should the x_csect.x_scnlen field be renumbered.
+       /* Should the x_csect.x_scnlen field be renumbered.
           Created by coff_pointerize_aux. */
 unsigned int fix_scnlen : 1;
 
-        /* Fix up an XCOFF C_BINCL/C_EINCL symbol.  The value is the
+       /* Fix up an XCOFF C_BINCL/C_EINCL symbol.  The value is the
           index into the line number entries.  Set by
           coff_slurp_symbol_table.  */
 unsigned int fix_line : 1;
 
-        /* The container for the symbol structure as read and translated
+       /* The container for the symbol structure as read and translated
            from the file. */
 
 union {
@@ -610,35 +621,35 @@ union {
 } combined_entry_type;
 
 
- /* Each canonical asymbol really looks like this: */
+/* Each canonical asymbol really looks like this: */
 
 typedef struct coff_symbol_struct
 {
-    /* The actual symbol which the rest of BFD works with */
+   /* The actual symbol which the rest of BFD works with */
 asymbol symbol;
 
-    /* A pointer to the hidden information for this symbol */
+   /* A pointer to the hidden information for this symbol */
 combined_entry_type *native;
 
-    /* A pointer to the linenumber information for this symbol */
+   /* A pointer to the linenumber information for this symbol */
 struct lineno_cache_entry *lineno;
 
-    /* Have the line numbers been relocated yet ? */
+   /* Have the line numbers been relocated yet ? */
 boolean done_lineno;
 } coff_symbol_type;
- /* COFF symbol classifications.  */
+/* COFF symbol classifications.  */
 
 enum coff_symbol_classification
 {
-   /* Global symbol.  */
+  /* Global symbol.  */
   COFF_SYMBOL_GLOBAL,
-   /* Common symbol.  */
+  /* Common symbol.  */
   COFF_SYMBOL_COMMON,
-   /* Undefined symbol.  */
+  /* Undefined symbol.  */
   COFF_SYMBOL_UNDEFINED,
-   /* Local symbol.  */
+  /* Local symbol.  */
   COFF_SYMBOL_LOCAL,
-   /* PE section symbol.  */
+  /* PE section symbol.  */
   COFF_SYMBOL_PE_SECTION
 };
 
@@ -817,12 +828,12 @@ typedef struct
        struct bfd_link_info *info,
        bfd *abfd,
        const char *name,
-       flagword flags, 
+       flagword flags,
        asection *section,
        bfd_vma value,
        const char *string,
        boolean copy,
-       boolean collect, 
+       boolean collect,
        struct bfd_link_hash_entry **hashp));
 
  boolean (*_bfd_coff_link_output_has_begun) PARAMS ((
