@@ -557,6 +557,8 @@ extern const bfd_target bfd_elf64_big_generic_vec;
 extern const bfd_target bfd_elf64_bigmips_vec;
 extern const bfd_target bfd_elf64_hppa_linux_vec;
 extern const bfd_target bfd_elf64_hppa_vec;
+extern const bfd_target bfd_elf64_ia64_aix_big_vec;
+extern const bfd_target bfd_elf64_ia64_aix_little_vec;
 extern const bfd_target bfd_elf64_ia64_big_vec;
 extern const bfd_target bfd_elf64_ia64_little_vec;
 extern const bfd_target bfd_elf64_little_generic_vec;
@@ -624,6 +626,7 @@ extern const bfd_target nlm32_sparc_vec;
 extern const bfd_target oasys_vec;
 extern const bfd_target pc532machaout_vec;
 extern const bfd_target pc532netbsd_vec;
+extern const bfd_target pdp11_aout_vec;
 extern const bfd_target pmac_xcoff_vec;
 extern const bfd_target ppcboot_vec;
 extern const bfd_target riscix_vec;
@@ -724,6 +727,8 @@ static const bfd_target * const _bfd_target_vector[] = {
 	&bfd_elf64_alpha_vec,
 	&bfd_elf64_hppa_vec,
 	&bfd_elf64_hppa_linux_vec,
+	&bfd_elf64_ia64_aix_little_vec,
+	&bfd_elf64_ia64_aix_big_vec,
 	&bfd_elf64_ia64_little_vec,
 	&bfd_elf64_ia64_big_vec,
 #endif
@@ -884,6 +889,7 @@ static const bfd_target * const _bfd_target_vector[] = {
 	&oasys_vec,
 #endif
 	&pc532machaout_vec,
+	&pdp11_aout_vec,
 #if 0
 	/* We have no way of distinguishing these from other a.out variants */
 	&aout_arm_big_vec,
