@@ -1,6 +1,6 @@
 SCRIPT_NAME=elf
 ELFSIZE=32
-OUTPUT_FORMAT="elf32-hppa"
+OUTPUT_FORMAT="elf32-hppa-linux"
 TEXT_START_ADDR=0x1000
 TARGET_PAGE_SIZE=0x1000
 MAXPAGESIZE=0x1000
