@@ -1,6 +1,7 @@
 /* This module handles expression trees.
-Copyright (C) 1991, 1993, 1994, 1995, 1996 Free Software Foundation, Inc.
-Written by Steve Chamberlain of Cygnus Support (sac@cygnus.com).
+   Copyright (C) 1991, 92, 93, 94, 95, 96, 97, 98, 99, 2000
+   Free Software Foundation, Inc.
+   Written by Steve Chamberlain of Cygnus Support <sac@cygnus.com>.
 
 This file is part of GLD, the Gnu Linker.
 
@@ -15,18 +16,16 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with GLD; see the file COPYING.  If not, write to
-the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+along with GLD; see the file COPYING.  If not, write to the Free
+Software Foundation, 59 Temple Place - Suite 330, Boston, MA
+02111-1307, USA.  */
 
-/*
-This module is in charge of working out the contents of expressions.
-
-It has to keep track of the relative/absness of a symbol etc. This is
-done by keeping all values in a struct (an etree_value_type) which
-contains a value, a section to which it is relative and a valid bit.
-
-*/
+/* This module is in charge of working out the contents of expressions.
 
+   It has to keep track of the relative/absness of a symbol etc. This
+   is done by keeping all values in a struct (an etree_value_type)
+   which contains a value, a section to which it is relative and a
+   valid bit.  */
 
 #include "bfd.h"
 #include "sysdep.h"
@@ -67,70 +66,71 @@ static void
 exp_print_token (code)
      token_code_type code;
 {
-  static CONST struct
-    {
-      token_code_type code;
-      char *name;
-    } table[] =
-      {
-	{ INT,	"int" },
-	{ REL, "relocateable" },
-	{ NAME,"NAME" },
-	{ PLUSEQ,"+=" },
-	{ MINUSEQ,"-=" },
-	{ MULTEQ,"*=" },
-	{ DIVEQ,"/=" },
-	{ LSHIFTEQ,"<<=" },
-	{ RSHIFTEQ,">>=" },
-	{ ANDEQ,"&=" },
-	{ OREQ,"|=" },
-	{ OROR,"||" },
-	{ ANDAND,"&&" },
-	{ EQ,"==" },
-	{ NE,"!=" },
-	{ LE,"<=" },
-	{ GE,">=" },
-	{ LSHIFT,"<<" },
-	{ RSHIFT,">>=" },
-	{ ALIGN_K,"ALIGN" },
-	{ BLOCK,"BLOCK" },
-	{ SECTIONS,"SECTIONS" },
-	{ SIZEOF_HEADERS,"SIZEOF_HEADERS" },
-	{ NEXT,"NEXT" },
-	{ SIZEOF,"SIZEOF" },
-	{ ADDR,"ADDR" },
-	{ LOADADDR,"LOADADDR" },
-	{ MEMORY,"MEMORY" },
-	{ DEFINED,"DEFINED" },
-	{ TARGET_K,"TARGET" },
-	{ SEARCH_DIR,"SEARCH_DIR" },
-	{ MAP,"MAP" },
-	{ QUAD,"QUAD" },
-	{ LONG,"LONG" },
-	{ SHORT,"SHORT" },
-	{ BYTE,"BYTE" },
-	{ ENTRY,"ENTRY" },
-	{ 0,(char *)NULL }
-      };
+  static CONST struct {
+    token_code_type code;
+    char *name;
+  } table[] = {
+    { INT, "int" },
+    { REL, "relocateable" },
+    { NAME, "NAME" },
+    { PLUSEQ, "+=" },
+    { MINUSEQ, "-=" },
+    { MULTEQ, "*=" },
+    { DIVEQ, "/=" },
+    { LSHIFTEQ, "<<=" },
+    { RSHIFTEQ, ">>=" },
+    { ANDEQ, "&=" },
+    { OREQ, "|=" },
+    { OROR, "||" },
+    { ANDAND, "&&" },
+    { EQ, "==" },
+    { NE, "!=" },
+    { LE, "<=" },
+    { GE, ">=" },
+    { LSHIFT, "<<" },
+    { RSHIFT, ">>=" },
+    { ALIGN_K, "ALIGN" },
+    { BLOCK, "BLOCK" },
+    { SECTIONS, "SECTIONS" },
+    { SIZEOF_HEADERS, "SIZEOF_HEADERS" },
+    { NEXT, "NEXT" },
+    { SIZEOF, "SIZEOF" },
+    { ADDR, "ADDR" },
+    { LOADADDR, "LOADADDR" },
+    { MEMORY, "MEMORY" },
+    { DEFINED, "DEFINED" },
+    { TARGET_K, "TARGET" },
+    { SEARCH_DIR, "SEARCH_DIR" },
+    { MAP, "MAP" },
+    { QUAD, "QUAD" },
+    { SQUAD, "SQUAD" },
+    { LONG, "LONG" },
+    { SHORT, "SHORT" },
+    { BYTE, "BYTE" },
+    { ENTRY, "ENTRY" },
+    { 0, (char *) NULL }
+  };
   unsigned int idx;
 
-  for (idx = 0; table[idx].name != (char*)NULL; idx++) {
-    if (table[idx].code == code) {
-      fprintf(config.map_file, "%s", table[idx].name);
-      return;
+  for (idx = 0; table[idx].name != (char *) NULL; idx++)
+    {
+      if (table[idx].code == code)
+	{
+	  fprintf (config.map_file, "%s", table[idx].name);
+	  return;
+	}
     }
-  }
   /* Not in table, just print it alone */
-  fprintf(config.map_file, "%c",code);
+  fprintf (config.map_file, "%c", code);
 }
 
-static void 
+static void
 make_abs (ptr)
      etree_value_type *ptr;
 {
-    asection *s = ptr->section->bfd_section;
-    ptr->value += s->vma;
-    ptr->section = abs_output_section;
+  asection *s = ptr->section->bfd_section;
+  ptr->value += s->vma;
+  ptr->section = abs_output_section;
 }
 
 static etree_value_type
@@ -138,29 +138,29 @@ new_abs (value)
      bfd_vma value;
 {
   etree_value_type new;
-  new.valid = true;
+  new.valid_p = true;
   new.section = abs_output_section;
   new.value = value;
   return new;
 }
 
-static void 
+static void
 check (os, name, op)
      lang_output_section_statement_type *os;
      const char *name;
      const char *op;
 {
   if (os == NULL)
-    einfo ("%F%P: %s uses undefined section %s\n", op, name);
+    einfo (_("%F%P: %s uses undefined section %s\n"), op, name);
   if (! os->processed)
-    einfo ("%F%P: %s forward reference of section %s\n", op, name);
+    einfo (_("%F%P: %s forward reference of section %s\n"), op, name);
 }
 
 etree_type *
 exp_intop (value)
      bfd_vma value;
 {
-  etree_type *new = (etree_type *) stat_alloc(sizeof(new->value));
+  etree_type *new = (etree_type *) stat_alloc (sizeof (new->value));
   new->type.node_code = INT;
   new->value.value = value;
   new->type.node_class = etree_value;
@@ -189,7 +189,7 @@ new_rel (value, section)
      lang_output_section_statement_type *section;
 {
   etree_value_type new;
-  new.valid = true;
+  new.valid_p = true;
   new.value = value;
   new.section = section;
   return new;
@@ -201,16 +201,16 @@ new_rel_from_section (value, section)
      lang_output_section_statement_type *section;
 {
   etree_value_type new;
-  new.valid = true;
+  new.valid_p = true;
   new.value = value;
   new.section = section;
 
-    new.value -= section->bfd_section->vma;
+  new.value -= section->bfd_section->vma;
 
   return new;
 }
 
-static etree_value_type 
+static etree_value_type
 fold_binary (tree, current_section, allocation_done, dot, dotp)
      etree_type *tree;
      lang_output_section_statement_type *current_section;
@@ -222,14 +222,14 @@ fold_binary (tree, current_section, allocation_done, dot, dotp)
 
   result = exp_fold_tree (tree->binary.lhs, current_section,
 			  allocation_done, dot, dotp);
-  if (result.valid)
+  if (result.valid_p)
     {
       etree_value_type other;
 
       other = exp_fold_tree (tree->binary.rhs,
 			     current_section,
-			     allocation_done, dot,dotp) ;
-      if (other.valid)
+			     allocation_done, dot, dotp);
+      if (other.valid_p)
 	{
 	  /* If the values are from different sections, or this is an
 	     absolute expression, make both the source arguments
@@ -257,214 +257,226 @@ fold_binary (tree, current_section, allocation_done, dot, dotp)
 	  else if (result.section != other.section
 		   || current_section == abs_output_section)
 	    {
-	      make_abs(&result);
-	      make_abs(&other);
+	      make_abs (&result);
+	      make_abs (&other);
 	    }
 
-	  switch (tree->type.node_code) 
+	  switch (tree->type.node_code)
 	    {
 	    case '%':
 	      if (other.value == 0)
-		einfo ("%F%S %% by zero\n");
+		einfo (_("%F%S %% by zero\n"));
 	      result.value = ((bfd_signed_vma) result.value
 			      % (bfd_signed_vma) other.value);
 	      break;
 
 	    case '/':
 	      if (other.value == 0)
-		einfo ("%F%S / by zero\n");
+		einfo (_("%F%S / by zero\n"));
 	      result.value = ((bfd_signed_vma) result.value
 			      / (bfd_signed_vma) other.value);
 	      break;
 
 #define BOP(x,y) case x : result.value = result.value y other.value; break;
-	      BOP('+',+);
-	      BOP('*',*);
-	      BOP('-',-);
-	      BOP(LSHIFT,<<);
-	      BOP(RSHIFT,>>);
-	      BOP(EQ,==);
-	      BOP(NE,!=);
-	      BOP('<',<);
-	      BOP('>',>);
-	      BOP(LE,<=);
-	      BOP(GE,>=);
-	      BOP('&',&);
-	      BOP('^',^);
-	      BOP('|',|);
-	      BOP(ANDAND,&&);
-	      BOP(OROR,||);
+	      BOP ('+', +);
+	      BOP ('*', *);
+	      BOP ('-', -);
+	      BOP (LSHIFT, <<);
+	      BOP (RSHIFT, >>);
+	      BOP (EQ, ==);
+	      BOP (NE, !=);
+	      BOP ('<', <);
+	      BOP ('>', >);
+	      BOP (LE, <=);
+	      BOP (GE, >=);
+	      BOP ('&', &);
+	      BOP ('^', ^);
+	      BOP ('|', |);
+	      BOP (ANDAND, &&);
+	      BOP (OROR, ||);
 
-	    case MAX:
+	    case MAX_K:
 	      if (result.value < other.value)
 		result = other;
 	      break;
 
-	    case MIN:
+	    case MIN_K:
 	      if (result.value > other.value)
 		result = other;
 	      break;
 
 	    default:
-	      FAIL();
+	      FAIL ();
 	    }
 	}
       else
 	{
-	  result.valid = false;
+	  result.valid_p = false;
 	}
     }
 
   return result;
 }
 
-etree_value_type 
+etree_value_type
 invalid ()
 {
   etree_value_type new;
-  new.valid = false;
+  new.valid_p = false;
   return new;
 }
 
-static etree_value_type 
+static etree_value_type
 fold_name (tree, current_section, allocation_done, dot)
      etree_type *tree;
      lang_output_section_statement_type *current_section;
-     lang_phase_type  allocation_done;
+     lang_phase_type allocation_done;
      bfd_vma dot;
 {
   etree_value_type result;
-  switch (tree->type.node_code) 
-      {
-      case SIZEOF_HEADERS:
-	if (allocation_done != lang_first_phase_enum) 
-	  {
-	    result = new_abs ((bfd_vma)
-			      bfd_sizeof_headers (output_bfd,
-						  link_info.relocateable));
-	  }
-	else
-	  {
-	    result.valid = false;
-	  }
-	break;
-      case DEFINED:
-	if (allocation_done == lang_first_phase_enum)
-	  result.valid = false;
-	else
-	  {
-	    struct bfd_link_hash_entry *h;
+  switch (tree->type.node_code)
+    {
+    case SIZEOF_HEADERS:
+      if (allocation_done != lang_first_phase_enum)
+	{
+	  result = new_abs ((bfd_vma)
+			    bfd_sizeof_headers (output_bfd,
+						link_info.relocateable));
+	}
+      else
+	{
+	  result.valid_p = false;
+	}
+      break;
+    case DEFINED:
+      if (allocation_done == lang_first_phase_enum)
+	result.valid_p = false;
+      else
+	{
+	  struct bfd_link_hash_entry *h;
 
-	    h = bfd_wrapped_link_hash_lookup (output_bfd, &link_info,
-					      tree->name.name,
-					      false, false, true);
-	    result.value = (h != (struct bfd_link_hash_entry *) NULL
-			    && (h->type == bfd_link_hash_defined
-				|| h->type == bfd_link_hash_defweak
-				|| h->type == bfd_link_hash_common));
-	    result.section = 0;
-	    result.valid = true;
-	  }
-	break;
-      case NAME:
-	result.valid = false;
-	if (tree->name.name[0] == '.' && tree->name.name[1] == 0)
-	  {
-	    if (allocation_done != lang_first_phase_enum)
-	      result = new_rel_from_section(dot, current_section);
-	    else
-	      result = invalid();
-	  }
-	else if (allocation_done != lang_first_phase_enum)
-	  {
-	    struct bfd_link_hash_entry *h;
+	  h = bfd_wrapped_link_hash_lookup (output_bfd, &link_info,
+					    tree->name.name,
+					    false, false, true);
+	  result.value = (h != (struct bfd_link_hash_entry *) NULL
+			  && (h->type == bfd_link_hash_defined
+			      || h->type == bfd_link_hash_defweak
+			      || h->type == bfd_link_hash_common));
+	  result.section = 0;
+	  result.valid_p = true;
+	}
+      break;
+    case NAME:
+      result.valid_p = false;
+      if (tree->name.name[0] == '.' && tree->name.name[1] == 0)
+	{
+	  if (allocation_done != lang_first_phase_enum)
+	    result = new_rel_from_section (dot, current_section);
+	  else
+	    result = invalid ();
+	}
+      else if (allocation_done != lang_first_phase_enum)
+	{
+	  struct bfd_link_hash_entry *h;
 
-	    h = bfd_wrapped_link_hash_lookup (output_bfd, &link_info,
-					      tree->name.name,
-					      false, false, true);
-	    if (h != NULL
-		&& (h->type == bfd_link_hash_defined
-		    || h->type == bfd_link_hash_defweak))
-	      {
-		if (bfd_is_abs_section (h->u.def.section))
-		  result = new_abs (h->u.def.value);
-		else if (allocation_done == lang_final_phase_enum
-			 || allocation_done == lang_allocating_phase_enum)
-		  {
-		    lang_output_section_statement_type *os;
-		
-		    os = (lang_output_section_statement_lookup
-			  (h->u.def.section->output_section->name));
+	  h = bfd_wrapped_link_hash_lookup (output_bfd, &link_info,
+					    tree->name.name,
+					    false, false, true);
+	  if (h != NULL
+	      && (h->type == bfd_link_hash_defined
+		  || h->type == bfd_link_hash_defweak))
+	    {
+	      if (bfd_is_abs_section (h->u.def.section))
+		result = new_abs (h->u.def.value);
+	      else if (allocation_done == lang_final_phase_enum
+		       || allocation_done == lang_allocating_phase_enum)
+		{
+		  asection *output_section;
 
-		    /* FIXME: Is this correct if this section is being
-		       linked with -R?  */
-		    result = new_rel ((h->u.def.value
-				       + h->u.def.section->output_offset),
-				      os);
-		  }
-	      }
-	    else if (allocation_done == lang_final_phase_enum)
-	      einfo ("%F%S: undefined symbol `%s' referenced in expression\n",
-		     tree->name.name);
-	  }
-	break;
+		  output_section = h->u.def.section->output_section;
+		  if (output_section == NULL)
+		    einfo (_("%X%S: unresolvable symbol `%s' referenced in expression\n"),
+			   tree->name.name);
+		  else
+		    {
+		      lang_output_section_statement_type *os;
 
-      case ADDR:
-	if (allocation_done != lang_first_phase_enum)
-	  {
-	    lang_output_section_statement_type *os;
+		      os = (lang_output_section_statement_lookup
+			    (bfd_get_section_name (output_bfd,
+						   output_section)));
 
-	    os = lang_output_section_find (tree->name.name);
-	    check (os, tree->name.name, "ADDR");
+		      /* FIXME: Is this correct if this section is
+			 being linked with -R?  */
+		      result = new_rel ((h->u.def.value
+					 + h->u.def.section->output_offset),
+					os);
+		    }
+		}
+	    }
+	  else if (allocation_done == lang_final_phase_enum)
+	    einfo (_("%F%S: undefined symbol `%s' referenced in expression\n"),
+		   tree->name.name);
+	}
+      break;
+
+    case ADDR:
+      if (allocation_done != lang_first_phase_enum)
+	{
+	  lang_output_section_statement_type *os;
+
+	  os = lang_output_section_find (tree->name.name);
+	  check (os, tree->name.name, "ADDR");
+	  result = new_rel (0, os);
+	}
+      else
+	result = invalid ();
+      break;
+
+    case LOADADDR:
+      if (allocation_done != lang_first_phase_enum)
+	{
+	  lang_output_section_statement_type *os;
+
+	  os = lang_output_section_find (tree->name.name);
+	  check (os, tree->name.name, "LOADADDR");
+	  if (os->load_base == NULL)
 	    result = new_rel (0, os);
-	  }
-	else
-	  result = invalid ();
-	break;
+	  else
+	    result = exp_fold_tree_no_dot (os->load_base,
+					   abs_output_section,
+					   allocation_done);
+	}
+      else
+	result = invalid ();
+      break;
 
-      case LOADADDR:
-	if (allocation_done != lang_first_phase_enum)
-	  {
-	    lang_output_section_statement_type *os;
+    case SIZEOF:
+      if (allocation_done != lang_first_phase_enum)
+	{
+	  int opb = bfd_octets_per_byte (output_bfd);
+	  lang_output_section_statement_type *os;
 
-	    os = lang_output_section_find (tree->name.name);
-	    check (os, tree->name.name, "LOADADDR");
-	    if (os->load_base == NULL)
-	      result = new_rel (0, os);
-	    else
-	      result = exp_fold_tree_no_dot (os->load_base,
-					     abs_output_section,
-					     allocation_done);
-	  }
-	else
-	  result = invalid ();
-	break;
+	  os = lang_output_section_find (tree->name.name);
+	  check (os, tree->name.name, "SIZEOF");
+	  result = new_abs (os->bfd_section->_raw_size / opb);
+	}
+      else
+	result = invalid ();
+      break;
 
-      case SIZEOF:
-	if (allocation_done != lang_first_phase_enum)
-	  {
-	    lang_output_section_statement_type *os;
-
-	    os = lang_output_section_find (tree->name.name);
-	    check (os, tree->name.name, "SIZEOF");
-	    result = new_abs (os->bfd_section->_raw_size);
-	  }
-	else
-	  result = invalid ();
-	break;
-
-      default:
-	FAIL();
-	break;
-      }
+    default:
+      FAIL ();
+      break;
+    }
 
   return result;
 }
-etree_value_type 
+
+etree_value_type
 exp_fold_tree (tree, current_section, allocation_done, dot, dotp)
      etree_type *tree;
      lang_output_section_statement_type *current_section;
-     lang_phase_type  allocation_done;
+     lang_phase_type allocation_done;
      bfd_vma dot;
      bfd_vma *dotp;
 {
@@ -472,11 +484,11 @@ exp_fold_tree (tree, current_section, allocation_done, dot, dotp)
 
   if (tree == NULL)
     {
-      result.valid = false;
+      result.valid_p = false;
       return result;
     }
 
-  switch (tree->type.node_class) 
+  switch (tree->type.node_class)
     {
     case etree_value:
       result = new_rel (tree->value.value, current_section);
@@ -484,7 +496,7 @@ exp_fold_tree (tree, current_section, allocation_done, dot, dotp)
 
     case etree_rel:
       if (allocation_done != lang_final_phase_enum)
-	result.valid = false;
+	result.valid_p = false;
       else
 	result = new_rel ((tree->rel.value
 			   + tree->rel.section->output_section->vma
@@ -492,30 +504,42 @@ exp_fold_tree (tree, current_section, allocation_done, dot, dotp)
 			  current_section);
       break;
 
+    case etree_assert:
+      result = exp_fold_tree (tree->assert_s.child,
+			      current_section,
+			      allocation_done, dot, dotp);
+      if (result.valid_p)
+	{
+	  if (! result.value)
+	    einfo ("%F%P: %s\n", tree->assert_s.message);
+	  return result;
+	}
+      break;
+
     case etree_unary:
       result = exp_fold_tree (tree->unary.child,
 			      current_section,
 			      allocation_done, dot, dotp);
-      if (result.valid)
+      if (result.valid_p)
 	{
-	  switch (tree->type.node_code) 
+	  switch (tree->type.node_code)
 	    {
 	    case ALIGN_K:
 	      if (allocation_done != lang_first_phase_enum)
 		result = new_rel_from_section (ALIGN_N (dot, result.value),
 					       current_section);
 	      else
-		result.valid = false;
+		result.valid_p = false;
 	      break;
 
 	    case ABSOLUTE:
-	      if (allocation_done != lang_first_phase_enum && result.valid)
+	      if (allocation_done != lang_first_phase_enum && result.valid_p)
 		{
 		  result.value += result.section->bfd_section->vma;
 		  result.section = abs_output_section;
 		}
-	      else 
-		result.valid = false;
+	      else
+		result.valid_p = false;
 	      break;
 
 	    case '~':
@@ -541,7 +565,7 @@ exp_fold_tree (tree, current_section, allocation_done, dot, dotp)
 		  result.value = ALIGN_N (dot, result.value);
 		}
 	      else
-		result.valid = false;
+		result.valid_p = false;
 	      break;
 
 	    default:
@@ -554,7 +578,7 @@ exp_fold_tree (tree, current_section, allocation_done, dot, dotp)
     case etree_trinary:
       result = exp_fold_tree (tree->trinary.cond, current_section,
 			      allocation_done, dot, dotp);
-      if (result.valid)
+      if (result.valid_p)
 	result = exp_fold_tree ((result.value
 				 ? tree->trinary.lhs
 				 : tree->trinary.rhs),
@@ -569,11 +593,12 @@ exp_fold_tree (tree, current_section, allocation_done, dot, dotp)
 
     case etree_assign:
     case etree_provide:
+    case etree_provided:
       if (tree->assign.dst[0] == '.' && tree->assign.dst[1] == 0)
 	{
 	  /* Assignment to dot can only be done during allocation */
-	  if (tree->type.node_class == etree_provide)
-	    einfo ("%F%S can not PROVIDE assignment to location counter\n");
+	  if (tree->type.node_class != etree_assign)
+	    einfo (_("%F%S can not PROVIDE assignment to location counter\n"));
 	  if (allocation_done == lang_allocating_phase_enum
 	      || (allocation_done == lang_final_phase_enum
 		  && current_section == abs_output_section))
@@ -582,12 +607,12 @@ exp_fold_tree (tree, current_section, allocation_done, dot, dotp)
 				      current_section,
 				      lang_allocating_phase_enum, dot,
 				      dotp);
-	      if (! result.valid)
-		einfo ("%F%S invalid assignment to location counter\n");
+	      if (! result.valid_p)
+		einfo (_("%F%S invalid assignment to location counter\n"));
 	      else
 		{
 		  if (current_section == NULL)
-		    einfo ("%F%S assignment to location counter invalid outside of SECTION\n");
+		    einfo (_("%F%S assignment to location counter invalid outside of SECTION\n"));
 		  else
 		    {
 		      bfd_vma nextdot;
@@ -597,11 +622,11 @@ exp_fold_tree (tree, current_section, allocation_done, dot, dotp)
 		      if (nextdot < dot
 			  && current_section != abs_output_section)
 			{
-			  einfo ("%F%S cannot move location counter backwards (from %V to %V)\n",
+			  einfo (_("%F%S cannot move location counter backwards (from %V to %V)\n"),
 				 dot, nextdot);
 			}
 		      else
-			*dotp = nextdot; 
+			*dotp = nextdot;
 		    }
 		}
 	    }
@@ -611,7 +636,7 @@ exp_fold_tree (tree, current_section, allocation_done, dot, dotp)
 	  result = exp_fold_tree (tree->assign.src,
 				  current_section, allocation_done,
 				  dot, dotp);
-	  if (result.valid)
+	  if (result.valid_p)
 	    {
 	      boolean create;
 	      struct bfd_link_hash_entry *h;
@@ -625,7 +650,7 @@ exp_fold_tree (tree, current_section, allocation_done, dot, dotp)
 	      if (h == (struct bfd_link_hash_entry *) NULL)
 		{
 		  if (tree->type.node_class == etree_assign)
-		    einfo ("%P%F:%s: hash creation failed\n",
+		    einfo (_("%P%F:%s: hash creation failed\n"),
 			   tree->assign.dst);
 		}
 	      else if (tree->type.node_class == etree_provide
@@ -642,6 +667,8 @@ exp_fold_tree (tree, current_section, allocation_done, dot, dotp)
 		  h->type = bfd_link_hash_defined;
 		  h->u.def.value = result.value;
 		  h->u.def.section = result.section->bfd_section;
+		  if (tree->type.node_class == etree_provide)
+		    tree->type.node_class = etree_provided;
 		}
 	    }
 	}
@@ -659,14 +686,14 @@ exp_fold_tree (tree, current_section, allocation_done, dot, dotp)
   return result;
 }
 
-static etree_value_type 
+static etree_value_type
 exp_fold_tree_no_dot (tree, current_section, allocation_done)
      etree_type *tree;
      lang_output_section_statement_type *current_section;
      lang_phase_type allocation_done;
 {
-return exp_fold_tree(tree, current_section, allocation_done, (bfd_vma)
-		     0, (bfd_vma *)NULL);
+  return exp_fold_tree (tree, current_section, allocation_done,
+			(bfd_vma) 0, (bfd_vma *) NULL);
 }
 
 etree_type *
@@ -682,15 +709,15 @@ exp_binop (code, lhs, rhs)
   value.binary.lhs = lhs;
   value.binary.rhs = rhs;
   value.type.node_class = etree_binary;
-  r = exp_fold_tree_no_dot(&value,
-			   abs_output_section,
-			   lang_first_phase_enum );
-  if (r.valid)
+  r = exp_fold_tree_no_dot (&value,
+			    abs_output_section,
+			    lang_first_phase_enum);
+  if (r.valid_p)
     {
-      return exp_intop(r.value);
+      return exp_intop (r.value);
     }
   new = (etree_type *) stat_alloc (sizeof (new->binary));
-  memcpy((char *)new, (char *)&value, sizeof(new->binary));
+  memcpy ((char *) new, (char *) &value, sizeof (new->binary));
   return new;
 }
 
@@ -708,17 +735,18 @@ exp_trinop (code, cond, lhs, rhs)
   value.trinary.cond = cond;
   value.trinary.rhs = rhs;
   value.type.node_class = etree_trinary;
-  r= exp_fold_tree_no_dot(&value,  (lang_output_section_statement_type
-				    *)NULL,lang_first_phase_enum);
-  if (r.valid) {
-    return exp_intop(r.value);
-  }
+  r = exp_fold_tree_no_dot (&value,
+			    (lang_output_section_statement_type *) NULL,
+			    lang_first_phase_enum);
+  if (r.valid_p)
+    {
+      return exp_intop (r.value);
+    }
   new = (etree_type *) stat_alloc (sizeof (new->trinary));
-  memcpy((char *)new,(char *) &value, sizeof(new->trinary));
+  memcpy ((char *) new, (char *) &value, sizeof (new->trinary));
   return new;
 }
 
-
 etree_type *
 exp_unop (code, child)
      int code;
@@ -730,17 +758,17 @@ exp_unop (code, child)
   value.unary.type.node_code = code;
   value.unary.child = child;
   value.unary.type.node_class = etree_unary;
-  r = exp_fold_tree_no_dot(&value,abs_output_section,
-			   lang_first_phase_enum);
-  if (r.valid) {
-    return exp_intop(r.value);
-  }
+  r = exp_fold_tree_no_dot (&value, abs_output_section,
+			    lang_first_phase_enum);
+  if (r.valid_p)
+    {
+      return exp_intop (r.value);
+    }
   new = (etree_type *) stat_alloc (sizeof (new->unary));
-  memcpy((char *)new, (char *)&value, sizeof(new->unary));
+  memcpy ((char *) new, (char *) &value, sizeof (new->unary));
   return new;
 }
 
-
 etree_type *
 exp_nameop (code, name)
      int code;
@@ -752,22 +780,19 @@ exp_nameop (code, name)
   value.name.name = name;
   value.name.type.node_class = etree_name;
 
-
-  r = exp_fold_tree_no_dot(&value,
-			   (lang_output_section_statement_type *)NULL,
-			   lang_first_phase_enum);
-  if (r.valid) {
-    return exp_intop(r.value);
-  }
+  r = exp_fold_tree_no_dot (&value,
+			    (lang_output_section_statement_type *) NULL,
+			    lang_first_phase_enum);
+  if (r.valid_p)
+    {
+      return exp_intop (r.value);
+    }
   new = (etree_type *) stat_alloc (sizeof (new->name));
-  memcpy((char *)new, (char *)&value, sizeof(new->name));
+  memcpy ((char *) new, (char *) &value, sizeof (new->name));
   return new;
 
 }
 
-
-
-
 etree_type *
 exp_assop (code, dst, src)
      int code;
@@ -778,18 +803,18 @@ exp_assop (code, dst, src)
 
   value.assign.type.node_code = code;
 
-
   value.assign.src = src;
   value.assign.dst = dst;
   value.assign.type.node_class = etree_assign;
 
 #if 0
-  if (exp_fold_tree_no_dot(&value, &result)) {
-    return exp_intop(result);
-  }
+  if (exp_fold_tree_no_dot (&value, &result))
+    {
+      return exp_intop (result);
+    }
 #endif
-  new = (etree_type*) stat_alloc (sizeof (new->assign));
-  memcpy((char *)new, (char *)&value, sizeof(new->assign));
+  new = (etree_type *) stat_alloc (sizeof (new->assign));
+  memcpy ((char *) new, (char *) &value, sizeof (new->assign));
   return new;
 }
 
@@ -810,80 +835,108 @@ exp_provide (dst, src)
   return n;
 }
 
-void 
+/* Handle ASSERT.  */
+
+etree_type *
+exp_assert (exp, message)
+     etree_type *exp;
+     const char *message;
+{
+  etree_type *n;
+
+  n = (etree_type *) stat_alloc (sizeof (n->assert_s));
+  n->assert_s.type.node_code = '!';
+  n->assert_s.type.node_class = etree_assert;
+  n->assert_s.child = exp;
+  n->assert_s.message = message;
+  return n;
+}
+
+void
 exp_print_tree (tree)
      etree_type *tree;
 {
-  switch (tree->type.node_class) {
-  case etree_value:
-    minfo ("0x%v", tree->value.value);
-    return;
-  case etree_rel:
-    if (tree->rel.section->owner != NULL)
-      minfo ("%B:", tree->rel.section->owner);
-    minfo ("%s+0x%v", tree->rel.section->name, tree->rel.value);
-    return;
-  case etree_assign:
-#if 0
-    if (tree->assign.dst->sdefs != (asymbol *)NULL){
-      fprintf(config.map_file,"%s (%x) ",tree->assign.dst->name,
-	      tree->assign.dst->sdefs->value);
-    }
-    else {
-      fprintf(config.map_file,"%s (UNDEFINED)",tree->assign.dst->name);
-    }
-#endif
-    fprintf(config.map_file,"%s",tree->assign.dst);
-    exp_print_token(tree->type.node_code);
-    exp_print_tree(tree->assign.src);
-    break;
-  case etree_provide:
-    fprintf (config.map_file, "PROVIDE (%s, ", tree->assign.dst);
-    exp_print_tree (tree->assign.src);
-    fprintf (config.map_file, ")");
-    break;
-  case etree_binary:
-    fprintf(config.map_file,"(");
-    exp_print_tree(tree->binary.lhs);
-    exp_print_token(tree->type.node_code);
-    exp_print_tree(tree->binary.rhs);
-    fprintf(config.map_file,")");
-    break;
-  case etree_trinary:
-    exp_print_tree(tree->trinary.cond);
-    fprintf(config.map_file,"?");
-    exp_print_tree(tree->trinary.lhs);
-    fprintf(config.map_file,":");
-    exp_print_tree(tree->trinary.rhs);
-    break;
-  case etree_unary:
-    exp_print_token(tree->unary.type.node_code);
-    if (tree->unary.child) 
+  switch (tree->type.node_class)
     {
-      
-    fprintf(config.map_file,"(");
-    exp_print_tree(tree->unary.child);
-    fprintf(config.map_file,")");
-  }
-    
-    break;
-  case etree_undef:
-    fprintf(config.map_file,"????????");
-    break;
-  case etree_name:
-    if (tree->type.node_code == NAME) {
-      fprintf(config.map_file,"%s", tree->name.name);
+    case etree_value:
+      minfo ("0x%v", tree->value.value);
+      return;
+    case etree_rel:
+      if (tree->rel.section->owner != NULL)
+	minfo ("%B:", tree->rel.section->owner);
+      minfo ("%s+0x%v", tree->rel.section->name, tree->rel.value);
+      return;
+    case etree_assign:
+#if 0
+      if (tree->assign.dst->sdefs != (asymbol *) NULL)
+	{
+	  fprintf (config.map_file, "%s (%x) ", tree->assign.dst->name,
+		   tree->assign.dst->sdefs->value);
+	}
+      else
+	{
+	  fprintf (config.map_file, "%s (UNDEFINED)", tree->assign.dst->name);
+	}
+#endif
+      fprintf (config.map_file, "%s", tree->assign.dst);
+      exp_print_token (tree->type.node_code);
+      exp_print_tree (tree->assign.src);
+      break;
+    case etree_provide:
+    case etree_provided:
+      fprintf (config.map_file, "PROVIDE (%s, ", tree->assign.dst);
+      exp_print_tree (tree->assign.src);
+      fprintf (config.map_file, ")");
+      break;
+    case etree_binary:
+      fprintf (config.map_file, "(");
+      exp_print_tree (tree->binary.lhs);
+      exp_print_token (tree->type.node_code);
+      exp_print_tree (tree->binary.rhs);
+      fprintf (config.map_file, ")");
+      break;
+    case etree_trinary:
+      exp_print_tree (tree->trinary.cond);
+      fprintf (config.map_file, "?");
+      exp_print_tree (tree->trinary.lhs);
+      fprintf (config.map_file, ":");
+      exp_print_tree (tree->trinary.rhs);
+      break;
+    case etree_unary:
+      exp_print_token (tree->unary.type.node_code);
+      if (tree->unary.child)
+	{
+	  fprintf (config.map_file, "(");
+	  exp_print_tree (tree->unary.child);
+	  fprintf (config.map_file, ")");
+	}
+      break;
+
+    case etree_assert:
+      fprintf (config.map_file, "ASSERT (");
+      exp_print_tree (tree->assert_s.child);
+      fprintf (config.map_file, ", %s)", tree->assert_s.message);
+      break;
+
+    case etree_undef:
+      fprintf (config.map_file, "????????");
+      break;
+    case etree_name:
+      if (tree->type.node_code == NAME)
+	{
+	  fprintf (config.map_file, "%s", tree->name.name);
+	}
+      else
+	{
+	  exp_print_token (tree->type.node_code);
+	  if (tree->name.name)
+	    fprintf (config.map_file, "(%s)", tree->name.name);
+	}
+      break;
+    default:
+      FAIL ();
+      break;
     }
-    else {
-      exp_print_token(tree->type.node_code);
-      if (tree->name.name)
-      fprintf(config.map_file,"(%s)", tree->name.name);
-    }
-    break;
-  default:
-    FAIL();
-    break;
-  }
 }
 
 bfd_vma
@@ -898,41 +951,41 @@ exp_get_vma (tree, def, name, allocation_done)
   if (tree != NULL)
     {
       r = exp_fold_tree_no_dot (tree, abs_output_section, allocation_done);
-      if (! r.valid && name != NULL)
-	einfo ("%F%S nonconstant expression for %s\n", name);
+      if (! r.valid_p && name != NULL)
+	einfo (_("%F%S nonconstant expression for %s\n"), name);
       return r.value;
     }
   else
     return def;
 }
 
-int 
-exp_get_value_int (tree,def,name, allocation_done)
+int
+exp_get_value_int (tree, def, name, allocation_done)
      etree_type *tree;
      int def;
      char *name;
      lang_phase_type allocation_done;
 {
-  return (int)exp_get_vma(tree,(bfd_vma)def,name, allocation_done);
+  return (int) exp_get_vma (tree, (bfd_vma) def, name, allocation_done);
 }
 
-
 bfd_vma
 exp_get_abs_int (tree, def, name, allocation_done)
      etree_type *tree;
-     int def;
+     int def ATTRIBUTE_UNUSED;
      char *name;
      lang_phase_type allocation_done;
 {
   etree_value_type res;
   res = exp_fold_tree_no_dot (tree, abs_output_section, allocation_done);
 
-  if (res.valid)
+  if (res.valid_p)
     {
       res.value += res.section->bfd_section->vma;
     }
-  else {
-    einfo ("%F%S non constant expression for %s\n",name);
-  }
+  else
+    {
+      einfo (_("%F%S non constant expression for %s\n"), name);
+    }
   return res.value;
 }
