@@ -41,7 +41,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 #include "ldemul.h"
 #include "ldctor.h"
 
-/* Somewhere above, sys/stat.h got included . . . . */
+/* Somewhere above, sys/stat.h got included . . . .  */
 #if !defined(S_ISDIR) && defined(S_IFDIR)
 #define	S_ISDIR(m) (((m) & S_IFMT) == S_IFDIR)
 #endif
@@ -65,7 +65,7 @@ const char *output_filename = "a.out";
 /* Name this program was invoked by.  */
 char *program_name;
 
-/* The file that we're creating */
+/* The file that we're creating.  */
 bfd *output_bfd = 0;
 
 /* Set by -G argument, for MIPS ECOFF target.  */
@@ -130,8 +130,7 @@ static boolean unattached_reloc PARAMS ((struct bfd_link_info *,
 static boolean notice PARAMS ((struct bfd_link_info *, const char *,
 			       bfd *, asection *, bfd_vma));
 
-static struct bfd_link_callbacks link_callbacks =
-{
+static struct bfd_link_callbacks link_callbacks = {
   add_archive_element,
   multiple_definition,
   multiple_common,
@@ -150,10 +149,10 @@ struct bfd_link_info link_info;
 static void
 remove_output ()
 {
-  if (output_filename) 
+  if (output_filename)
     {
       if (output_bfd && output_bfd->iostream)
-	fclose((FILE *)(output_bfd->iostream));
+	fclose ((FILE *) (output_bfd->iostream));
       if (delete_output_file_on_failure)
 	unlink (output_filename);
     }
@@ -200,6 +199,8 @@ main (argc, argv)
   config.build_constructors = true;
   config.dynamic_link = false;
   config.has_shared = false;
+  config.split_by_reloc = (unsigned) -1;
+  config.split_by_file = (bfd_size_type) -1;
   command_line.force_common_definition = false;
   command_line.interpreter = NULL;
   command_line.rpath = NULL;
@@ -223,6 +224,7 @@ main (argc, argv)
   link_info.traditional_format = false;
   link_info.optimize = false;
   link_info.no_undefined = false;
+  link_info.allow_shlib_undefined = false;
   link_info.strip = strip_none;
   link_info.discard = discard_none;
   link_info.keep_memory = true;
@@ -248,7 +250,6 @@ main (argc, argv)
   force_make_executable = false;
   config.magic_demand_paged = true;
   config.text_read_only = true;
-  config.make_executable = true;
 
   emulation = get_emulation (argc, argv);
   ldemul_choose_mode (emulation);
@@ -327,7 +328,6 @@ main (argc, argv)
 
   ldemul_after_parse ();
 
-
   if (config.map_filename)
     {
       if (strcmp (config.map_filename, "-") == 0)
@@ -346,17 +346,16 @@ main (argc, argv)
 	}
     }
 
-
   lang_process ();
 
   /* Print error messages for any missing symbols, for any warning
-     symbols, and possibly multiple definitions */
+     symbols, and possibly multiple definitions.  */
 
   if (! link_info.relocateable)
     {
       /* Look for a text section and switch the readonly attribute in it.  */
-      asection * found = bfd_get_section_by_name (output_bfd, ".text");
-    
+      asection *found = bfd_get_section_by_name (output_bfd, ".text");
+
       if (found != (asection *) NULL)
 	{
 	  if (config.text_read_only)
@@ -402,12 +401,12 @@ main (argc, argv)
 	einfo (_("%F%B: final close failed: %E\n"), output_bfd);
 
       /* If the --force-exe-suffix is enabled, and we're making an
-	 executable file and it doesn't end in .exe, copy it to one which does. */
-
+	 executable file and it doesn't end in .exe, copy it to one
+	 which does.  */
       if (! link_info.relocateable && command_line.force_exe_suffix)
 	{
 	  int len = strlen (output_filename);
-	  if (len < 4 
+	  if (len < 4
 	      || (strcasecmp (output_filename + len - 4, ".exe") != 0
 		  && strcasecmp (output_filename + len - 4, ".dll") != 0))
 	    {
@@ -498,7 +497,7 @@ get_emulation (argc, argv)
 		}
 	      else
 		{
-		  einfo(_("%P%F: missing argument to -m\n"));
+		  einfo (_("%P%F: missing argument to -m\n"));
 		}
 	    }
 	  else if (strcmp (argv[i], "-mips1") == 0
@@ -547,7 +546,7 @@ check_for_scripts_dir (dir, append)
 
   dirlen = strlen (dir);
   /* sizeof counts the terminating NUL.  */
-  buf = (char *) xmalloc (dirlen + sizeof("/ldscripts"));
+  buf = (char *) xmalloc (dirlen + sizeof ("/ldscripts"));
   sprintf (buf, "%s/ldscripts", dir);
 
   res = stat (buf, &s) == 0 && S_ISDIR (s.st_mode);
@@ -594,7 +593,8 @@ set_scripts_dir ()
     }
 
   if (check_for_scripts_dir (SCRIPTDIR, true))
-    return;			/* We've been installed normally.  */
+    /* We've been installed normally.  */
+    return;
 
   /* Look for "ldscripts" in the dir where our binary is.  */
   end = strrchr (program_name, '/');
@@ -622,14 +622,16 @@ set_scripts_dir ()
   dir[dirlen] = '\0';
 
   if (check_for_scripts_dir (dir, true))
-    return;			/* Don't free dir.  */
+    /* Don't free dir.  */
+    return;
 
   /* Look for "ldscripts" in <the dir where our binary is>/../lib.  */
   strcpy (dir + dirlen, "/../lib");
   if (check_for_scripts_dir (dir, true))
     return;
 
-  free (dir);			/* Well, we tried.  */
+  /* Well, we tried.  */
+  free (dir);
 }
 
 void
@@ -644,7 +646,7 @@ add_ysym (name)
 				   bfd_hash_newfunc,
 				   61))
 	einfo (_("%P%F: bfd_hash_table_init failed: %E\n"));
-    }      
+    }
 
   if (bfd_hash_lookup (link_info.notice_hash, name, true, true)
       == (struct bfd_hash_entry *) NULL)
@@ -741,7 +743,6 @@ add_keepsyms_file (filename)
 /* This is called when BFD has decided to include an archive member in
    a link.  */
 
-/*ARGSUSED*/
 static boolean
 add_archive_element (info, abfd, name)
      struct bfd_link_info *info ATTRIBUTE_UNUSED;
@@ -856,7 +857,6 @@ add_archive_element (info, abfd, name)
 /* This is called when BFD has discovered a symbol which is defined
    multiple times.  */
 
-/*ARGSUSED*/
 static boolean
 multiple_definition (info, name, obfd, osec, oval, nbfd, nsec, nval)
      struct bfd_link_info *info ATTRIBUTE_UNUSED;
@@ -885,6 +885,13 @@ multiple_definition (info, name, obfd, osec, oval, nbfd, nsec, nval)
 	 nbfd, nsec, nval, name);
   if (obfd != (bfd *) NULL)
     einfo (_("%D: first defined here\n"), obfd, osec, oval);
+
+  if (command_line.relax)
+    {
+      einfo (_("%P: Disabling relaxation: it will not work with multiple definitions\n"));
+      command_line.relax = 0;
+    }
+
   return true;
 }
 
@@ -893,7 +900,6 @@ multiple_definition (info, name, obfd, osec, oval, nbfd, nsec, nval)
    or when two common symbols are found.  We only do something if
    -warn-common was used.  */
 
-/*ARGSUSED*/
 static boolean
 multiple_common (info, name, obfd, otype, osize, nbfd, ntype, nsize)
      struct bfd_link_info *info ATTRIBUTE_UNUSED;
@@ -960,7 +966,6 @@ multiple_common (info, name, obfd, otype, osize, nbfd, ntype, nsize)
    entry in the linker hash table for the set.  SECTION and VALUE
    represent a value which should be added to the set.  */
 
-/*ARGSUSED*/
 static boolean
 add_to_set (info, h, reloc, abfd, section, value)
      struct bfd_link_info *info ATTRIBUTE_UNUSED;
@@ -1049,8 +1054,7 @@ constructor_callback (info, constructor, name, abfd, section, value)
 /* A structure used by warning_callback to pass information through
    bfd_map_over_sections.  */
 
-struct warning_callback_info
-{
+struct warning_callback_info {
   boolean found;
   const char *warning;
   const char *symbol;
@@ -1059,7 +1063,6 @@ struct warning_callback_info
 
 /* This is called when there is a reference to a warning symbol.  */
 
-/*ARGSUSED*/
 static boolean
 warning_callback (info, warning, symbol, abfd, section, address)
      struct bfd_link_info *info ATTRIBUTE_UNUSED;
@@ -1181,7 +1184,6 @@ warning_find_reloc (abfd, sec, iarg)
 
 /* This is called when an undefined symbol is found.  */
 
-/*ARGSUSED*/
 static boolean
 undefined_symbol (info, name, abfd, section, address, fatal)
      struct bfd_link_info *info ATTRIBUTE_UNUSED;
@@ -1262,7 +1264,6 @@ undefined_symbol (info, name, abfd, section, address, fatal)
 
 /* This is called when a reloc overflows.  */
 
-/*ARGSUSED*/
 static boolean
 reloc_overflow (info, name, reloc_name, addend, abfd, section, address)
      struct bfd_link_info *info ATTRIBUTE_UNUSED;
@@ -1286,7 +1287,6 @@ reloc_overflow (info, name, reloc_name, addend, abfd, section, address)
 
 /* This is called when a dangerous relocation is made.  */
 
-/*ARGSUSED*/
 static boolean
 reloc_dangerous (info, message, abfd, section, address)
      struct bfd_link_info *info ATTRIBUTE_UNUSED;
@@ -1306,7 +1306,6 @@ reloc_dangerous (info, message, abfd, section, address)
 /* This is called when a reloc is being generated attached to a symbol
    that is not being output.  */
 
-/*ARGSUSED*/
 static boolean
 unattached_reloc (info, name, abfd, section, address)
      struct bfd_link_info *info ATTRIBUTE_UNUSED;
